"""
Wrapper classes to enhance the functionality of native pipeline classes conforming with
the `scikit-learn` API.
"""

from ._wrapper import *
